==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/et.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Manage valguskastireklaam Gallary parameetrid");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Manage Galerii");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Suurt pilti Laius");
define('MANAGE_GALLERY_FULL_HEIGHT', "Suurt pilti Kõrgus");
define('MANAGE_GALLERY_THUMB_WIDTH', "Pisipilt Laius");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Pisipilt Kõrgus");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Säilita Thumb Kuvasuhe");
define('MANAGE_GALLERY_SHOW_TITLES', "Näita pealkirju");
define('MANAGE_GALLERY_DISABLE_SORT', "Lülita Sorteeri");
define('MANAGE_GALLERY_DELETE_IMAGE', "Kustuta Pilt");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Säästa Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Vajuta &quot;Uuenda&quot; avaldada <br /> lataamillesi pilte.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Kõik pildid on suurust ja seaded on salvestatud.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Tekkis viga saneerimist pilte või salvestada seaded.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Sinu pilti (id) on üles laaditud.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Tekkis viga Pildi üleslaadimisel (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Fail, mida soovid üles laadida ei ole pilti.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Fail, mida soovid üles laadida on liiga suur.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Pealkirja on salvestatud.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Oled sa kindel, et soovid kustutada pilti");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Pilt on kustutatud.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Tekkis viga pilti kustutamata.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Salvestamine parameetrid ja nende suurust muuta pilte, palun oota ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Üleslaadimine, palun oota ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Sortimisjärjekorda ei ole salvestatud. Kas soovite salvestada sortimisjärjestusel?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Pilt sortimisjärjestusel on salvestatud.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Tekkis viga salvestamisel omamoodi.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/et.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Manage valguskastireklaam Gallary parameetrid");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Manage Galerii");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Suurt pilti Laius");
define('MANAGE_GALLERY_FULL_HEIGHT', "Suurt pilti Kõrgus");
define('MANAGE_GALLERY_THUMB_WIDTH', "Pisipilt Laius");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Pisipilt Kõrgus");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Säilita Thumb Kuvasuhe");
define('MANAGE_GALLERY_SHOW_TITLES', "Näita pealkirju");
define('MANAGE_GALLERY_DISABLE_SORT', "Lülita Sorteeri");
define('MANAGE_GALLERY_DELETE_IMAGE', "Kustuta Pilt");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Säästa Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Vajuta &quot;Uuenda&quot; avaldada <br /> lataamillesi pilte.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Kõik pildid on suurust ja seaded on salvestatud.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Tekkis viga saneerimist pilte või salvestada seaded.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Sinu pilti (id) on üles laaditud.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Tekkis viga Pildi üleslaadimisel (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Fail, mida soovid üles laadida ei ole pilti.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Fail, mida soovid üles laadida on liiga suur.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Pealkirja on salvestatud.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Oled sa kindel, et soovid kustutada pilti");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Pilt on kustutatud.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Tekkis viga pilti kustutamata.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Salvestamine parameetrid ja nende suurust muuta pilte, palun oota ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Üleslaadimine, palun oota ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Sortimisjärjekorda ei ole salvestatud. Kas soovite salvestada sortimisjärjestusel?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Pilt sortimisjärjestusel on salvestatud.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Tekkis viga salvestamisel omamoodi.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Fail, mida proovite üles laadida, on suurem kui &#39;upload_max_filesize&#39; või &#39;post_max_size&#39; PHP seaded. Nende limiitide suurendamiseks pöörduge oma süsteemi administraatori poole.");
?>
